==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/it/admin/custom_fields/general.php <==
<?php

return array(
    'custom_fields'		        => 'Campi Personalizzati',
    'field'		                => 'Campo',
    'about_fieldsets_title'		=> 'Fileldsets',
    'about_fieldsets_text'		=> 'I Fieldsets ti permettono di creare gruppi di campi personalizzati che sono frequentemente riutilizzati per modelli specifici di asset.',
    'custom_format'             => 'Formato personalizzato...',
    'encrypt_field'      	        => 'Crittografare il valore di questo campo nel database',
    'encrypt_field_help'      => 'ATTENZIONE: Se il campo viene crittografato non sarà possibile cercarlo.',
    'encrypted'      	        => 'Crittografato',
    'fieldset'      	        => 'Fieldset',
    'qty_fields'      	      => 'Campi quantità',
    'fieldsets'      	        => 'Fieldsets',
    'fieldset_name'           => 'Nome Fieldset',
    'field_name'              => 'Nome campo',
    'field_values'            => 'Valori del campo',
    'field_values_help'       => 'Aggiungi opzioni selezionabili, una per riga. Le righe vuote diverse dalla prima riga saranno ignorate.',
    'field_element'           => 'Elemento del form',
    'field_element_short'     => 'Elemento',
    'field_format'            => 'Formato',
    'field_custom_format'     => 'Formato personalizzato',
    'field_custom_format_help'     => 'Questo campo ti permette di utilizzare un\'espressione regex per la validazione. Deve iniziare con "regex:" - ad esempio, per validare il valore di un campo personalizzato contenente un IMEI (15 cifre numeriche), userai <code>regex:/^[0-9]{15}$/</code>.',
    'required'   		          => 'Obbligatorio',
    'req'   		              => 'Obbl.',
    'used_by_models'   		    => 'Usato dai Modelli',
    'order'   		            => 'Ordine',
    'create_fieldset'         => 'Nuovo fieldset',
    'create_field'            => 'Nuovo campo personalizzato',
    'value_encrypted'      	        => 'Il valore di questo campo viene crittografato nel database. Solo gli utenti amministratori saranno in grado di visualizzare il valore decrittografato',
    'show_in_email'     => 'Includere il valore di questo campo nelle e-mail di checkout inviate all\'utente? I campi crittografati non possono essere inclusi nelle e-mail.',
);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/it/admin/custom_fields/general.php <==
<?php

return [
    'custom_fields'		        => 'Campi Personalizzati',
    'manage'                    => 'Manage',
    'field'		                => 'Campo',
    'about_fieldsets_title'		=> 'Fileldsets',
    'about_fieldsets_text'		=> 'Fieldsets allow you to create groups of custom fields that are frequently re-used for specific asset model types.',
    'custom_format'             => 'Custom Regex format...',
    'encrypt_field'      	        => 'Crittografare il valore di questo campo nel database',
    'encrypt_field_help'      => 'ATTENZIONE: Se il campo viene crittografato non sarà possibile cercarlo.',
    'encrypted'      	        => 'Crittografato',
    'fieldset'      	        => 'Fieldset',
    'qty_fields'      	      => 'Campi quantità',
    'fieldsets'      	        => 'Fieldsets',
    'fieldset_name'           => 'Nome Fieldset',
    'field_name'              => 'Nome campo',
    'field_values'            => 'Valori del campo',
    'field_values_help'       => 'Aggiungi opzioni selezionabili, una per riga. Le righe vuote diverse dalla prima riga saranno ignorate.',
    'field_element'           => 'Elemento del form',
    'field_element_short'     => 'Elemento',
    'field_format'            => 'Formato',
    'field_custom_format'     => 'Formato personalizzato',
    'field_custom_format_help'     => 'Questo campo ti permette di utilizzare un\'espressione regex per la validazione. Deve iniziare con "regex:" - ad esempio, per validare il valore di un campo personalizzato contenente un IMEI (15 cifre numeriche), userai <code>regex:/^[0-9]{15}$/</code>.',
    'required'   		          => 'Obbligatorio',
    'req'   		              => 'Obbl.',
    'used_by_models'   		    => 'Usato dai Modelli',
    'order'   		            => 'Ordine',
    'create_fieldset'         => 'Nuovo fieldset',
    'create_fieldset_title' => 'Create a new fieldset',
    'create_field'            => 'Nuovo campo personalizzato',
    'create_field_title' => 'Create a new custom field',
    'value_encrypted'      	        => 'Il valore di questo campo viene crittografato nel database. Solo gli utenti amministratori saranno in grado di visualizzare il valore decrittografato',
    'show_in_email'     => 'Includere il valore di questo campo nelle e-mail di checkout inviate all\'utente? I campi crittografati non possono essere inclusi nelle e-mail.',
    'help_text' => 'Help Text',
    'help_text_description' => 'This is optional text that will appear below the form elements while editing an asset to provide context on the field.',
    'about_custom_fields_title' => 'About Custom Fields',
    'about_custom_fields_text' => 'Custom fields allow you to add arbitrary attributes to assets.',
    'add_field_to_fieldset' => 'Add Field to Fieldset',
    'make_optional' => 'Required - click to make optional',
    'make_required' => 'Optional - click to make required',
    'reorder' => 'Reorder',
    'db_field' => 'DB Field',
    'db_convert_warning' => 'WARNING. This field is in the custom fields table as <code> :db_column </code> but should be :expected </code>.',
    'is_unique' => 'Questo valore deve essere univoco per tutti i beni',
    'unique' => 'Univoco',
];
